@@ -286,6 +286,56 @@ if PLOT:
 # mlab.title('Coils which minimize the transient effects of conductive shield')
 
 
+#%%
+
+
+#%%
+# Plot cross-section of magnetic field and magnetic potential of the discretized loops
+
+
+import matplotlib.pyplot as plt
+
+x = y = np.linspace(-1, 1, 40)
+X, Y = np.meshgrid(x, y, indexing="ij")
+
+
+points = np.zeros((X.flatten().shape[0], 3))
+points[:, 0] = X.flatten()
+points[:, 1] = Y.flatten()
+
+B = coil.B_coupling(points) @ coil.s
+
+
+mlab.quiver3d(*points.T, *B.T)
+
+# U = U.reshape(x.shape[0], y.shape[0])
+# B = B.T[:2].reshape(2, x.shape[0], y.shape[0])
+
+# from bfieldtools.viz import plot_cross_section
+
+# lw = np.sqrt(B[0] ** 2 + B[1] ** 2)
+
+# lw = 2 * lw / np.max(lw)
+
+# plot_cross_section(X, Y, U, log=False, contours=False)
+
+# seed_points = points[:, :2] * 0.3
+
+# plt.streamplot(
+#     x,
+#     y,
+#     B[0],
+#     B[1],
+#     density=2,
+#     linewidth=lw,
+#     color="k",
+#     integration_direction="both",
+#     start_points=seed_points,
+# )
+
+
+# plt.tight_layout()
+
 #%%
 # For comparison, let's see how the coils look when we ignore the conducting shield
 
@@ -342,6 +392,24 @@ if PLOT:
         mlab.savefig(SAVE_PATH + "eddy_no.png", figure=f, magnification=4)
         mlab.close()
 
+
+#%%
+
+import matplotlib.pyplot as plt
+
+x = y = np.linspace(-1, 1, 40)
+X, Y = np.meshgrid(x, y, indexing="ij")
+
+
+points = np.zeros((X.flatten().shape[0], 3))
+points[:, 0] = X.flatten()
+points[:, 1] = Y.flatten()
+
+B = coil.B_coupling(points) @ coil.unshielded_s
+
+
+mlab.quiver3d(*points.T, *B.T)
+
 #%%
 # Finally, let's compare the time-courses
 
